import pygame
from pygame.locals import *
import ode
import main

class GameObject:
	def __init__(self, dimensions, centre):
		self.geom = ode.GeomBox(main.space, (dimensions[0]/200.0, dimensions[1]/200.0,5))
		self.geom.setPosition((centre[0]/200.0,centre[1]/200.0,0))
		self.dimensions = dimensions
		self.centre= centre
		self.topleft = (centre[0] - dimensions[0]/2, centre[1] - dimensions[1]/2)
		main.renderlist.append(self)
	def draw(self, surface):
		pygame.draw.rect(surface, (55,0,200), self.topleft+self.dimensions)

class Player:
	def __init__(self, startpos):
		self.body = ode.Body(main.world)
		M = ode.Mass()
		M.setSphere(2500,0.05)
		self.body.setMass(M)
		self.body.setPosition((startpos[0]/200,startpos[1]/200,0))
		self.geom = ode.GeomSphere(main.space, 0.05)
		self.geom.setBody(self.body)
		main.renderlist.append(self)
	def draw(self, srf):
		pos = self.body.getPosition()
		pos = (pos[0]*200,pos[1]*200)
		pygame.draw.circle(srf, (55,0,200), (int(pos[0]),int(pos[1])), 10, 0)
		
class Rope:
	def __init__(self, player, target):
		self.coords = target
		self.joint = ode.BallJoint(main.world)
		self.joint.attach(player.body, ode.environment)
		self.joint.setAnchor((target[0]/200.0,target[1]/200.0, 0))
	def draw(self, srf):
		x1,y1,z1 = self.joint.getAnchor()
		b = self.joint.getBody(0)
		x2,y2,z2 = b.getPosition()
		pygame.draw.line(srf, (55,0,200), (x1*200,y1*200), (x2*200,y2*200), 2)
		
class Grapple(ode.Body):
	def __init__(self, world):
		ode.Body.__init__(self, world)
		M = ode.Mass()
		M.setSphereTotal(5,0.015)
		self.setMass(M)
		playerpos = main.player.body.getPosition()
		playerVel = main.player.body.getLinearVel()
		self.setPosition((playerpos[0], playerpos[1], 0))
		self.setGravityMode(0)
		self.setLinearVel((playerVel[0],-1,0))
		self.geom = ode.GeomSphere(main.space, 0.015)
		self.geom.setBody(self)
		#main.renderlist.append(self)
		self.isGrapple = 1
	def draw(self, srf):
		pos = self.getPosition()
		pos = (pos[0]*200,pos[1]*200)
		pygame.draw.circle(srf, (55,0,200), (int(pos[0]),int(pos[1])), 2, 0)

class Exit(GameObject):
	def __init__(self, centre):
		GameObject.__init__(self, (30,30),centre)
	def draw(self, surface):
		pygame.draw.rect(surface, (200,0,30), self.topleft+self.dimensions)